/* simple DFSG free reimplementation of the CC licensed original */

package org.jgroups.annotations;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

@Retention(RetentionPolicy.SOURCE)
public @interface Immutable { }
